@@ -49,7 +49,7 @@ class MPRelaxSet2D(DictSet):
         :param structure: Structure
         :param kwargs: Same as those supported by DictSet.
         """
-        incar = _read_user_incar('Relax2D')
+        incar = _read_user_incar('Relax2D.txt')
         super().__init__(structure, MPRelaxSet2D.CONFIG, user_incar_settings={incar}, **kwargs)
         self.kwargs = kwargs
 
